@@ -37,11 +37,11 @@ journal_add_header(char* title)
   if (!myjournal) 
     return -1;
   myjournal[0] = 
-    g_strdup_printf("<html>\n<head>\n<title>%s</title>\n</head>",
+    g_strdup_printf("<html>\n<head>\n<title>%s</title>\n<link rel=\"stylesheet\" type=\"text/css\" href=\"/usr/share/gpe-timesheet/gpe-timesheet.css\" />\n</head>",
       title);
   myjournal[1] = g_strdup_printf("<body>\n<h1>%s %s</h1>\n<p>",
     _("Journal for"), title);
-  myjournal[2] = g_strdup("<table WIDTH=100% BORDER=0 CELLPADDING=0 CELLSPACING=0>\n");
+  myjournal[2] = g_strdup("<table WIDTH=100% BORDER=1 CELLPADDING=0 CELLSPACING=0>\n");
   myjournal[3] = g_strdup_printf("<tr><th align=\"left\">%s</th><th " \
     "align=\"left\">%s</th><th align=\"left\">%s</th><th align=\"left\">%s</th><th align=\"left\">%s</th></tr>",
   	_("Start"), _("Comment"), _("End"), _("Comment"),  _("Duration"));
@@ -66,7 +66,7 @@ journal_add_line(time_t tstart, time_t tstop,
   starttm = ctime_r(&tstart, starttm);
   stoptm = ctime_r(&tstop, stoptm);
 
-  sprintf(duration, "%.2i h. %.2i min. %.2i sec.\n", (tstop - tstart)/3600, ((tstop - tstart)%3600)/60, 
+  sprintf(duration, "%.2ld h. %.2ld min. %.2ld sec.\n", (tstop - tstart)/3600, ((tstop - tstart)%3600)/60, 
   		(((tstop - tstart)%3600)%60));
   myjournal = realloc(myjournal,sizeof(char*)*(++jlen));
   myjournal[jlen - 2] = 
